from distutils.core import setup

setup(
    name='biocyc',
    version='0.1.0',
    author='Martin Fitzpatrick',
    author_email='martin.fitzpatrick@gmail.com',
    packages=['biocyc'],
    url='https://github.com/mfitzp/biocyc',
    #license='LICENSE.txt',
    description='Python interface to BioCyc REST API with caching mechanism',
    #long_description=open('README.txt').read()
    )
